"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class AccessControlConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATALOGS_FIELD_NUMBER: builtins.int
    SCHEMAS_FIELD_NUMBER: builtins.int
    TABLES_FIELD_NUMBER: builtins.int
    FUNCTIONS_FIELD_NUMBER: builtins.int
    PROCEDURES_FIELD_NUMBER: builtins.int
    QUERIES_FIELD_NUMBER: builtins.int
    SYSTEM_SESSION_PROPERTIES_FIELD_NUMBER: builtins.int
    CATALOG_SESSION_PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def catalogs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CatalogAccessRule]:
        """Catalog access control rules."""

    @property
    def schemas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SchemaAccessRule]:
        """Schema access control rules."""

    @property
    def tables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TableAccessRule]:
        """Table access control rules."""

    @property
    def functions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FunctionAccessRule]:
        """Function access control rules."""

    @property
    def procedures(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProcedureAccessRule]:
        """Procedures access control rules."""

    @property
    def queries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___QueryAccessRule]:
        """Queries access control rules."""

    @property
    def system_session_properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SystemSessionPropertyAccessRule]:
        """System session property access control rules."""

    @property
    def catalog_session_properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CatalogSessionPropertyAccessRule]:
        """Catalog session property access control rules."""

    def __init__(
        self,
        *,
        catalogs: collections.abc.Iterable[global___CatalogAccessRule] | None = ...,
        schemas: collections.abc.Iterable[global___SchemaAccessRule] | None = ...,
        tables: collections.abc.Iterable[global___TableAccessRule] | None = ...,
        functions: collections.abc.Iterable[global___FunctionAccessRule] | None = ...,
        procedures: collections.abc.Iterable[global___ProcedureAccessRule] | None = ...,
        queries: collections.abc.Iterable[global___QueryAccessRule] | None = ...,
        system_session_properties: collections.abc.Iterable[global___SystemSessionPropertyAccessRule] | None = ...,
        catalog_session_properties: collections.abc.Iterable[global___CatalogSessionPropertyAccessRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["catalog_session_properties", b"catalog_session_properties", "catalogs", b"catalogs", "functions", b"functions", "procedures", b"procedures", "queries", b"queries", "schemas", b"schemas", "system_session_properties", b"system_session_properties", "tables", b"tables"]) -> None: ...

global___AccessControlConfig = AccessControlConfig

@typing.final
class CatalogAccessRuleMatcher(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class CatalogIds(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ANY_FIELD_NUMBER: builtins.int
        @property
        def any(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            any: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["any", b"any"]) -> None: ...

    @typing.final
    class CatalogNames(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ANY_FIELD_NUMBER: builtins.int
        @property
        def any(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            any: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["any", b"any"]) -> None: ...

    NAME_REGEXP_FIELD_NUMBER: builtins.int
    IDS_FIELD_NUMBER: builtins.int
    NAMES_FIELD_NUMBER: builtins.int
    name_regexp: builtins.str
    """Catalog name regexp the rule is applied to."""
    @property
    def ids(self) -> global___CatalogAccessRuleMatcher.CatalogIds:
        """Catalog IDs rule is applied to."""

    @property
    def names(self) -> global___CatalogAccessRuleMatcher.CatalogNames:
        """Catalog names rule is applied to."""

    def __init__(
        self,
        *,
        name_regexp: builtins.str = ...,
        ids: global___CatalogAccessRuleMatcher.CatalogIds | None = ...,
        names: global___CatalogAccessRuleMatcher.CatalogNames | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ids", b"ids", "match_by", b"match_by", "name_regexp", b"name_regexp", "names", b"names"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ids", b"ids", "match_by", b"match_by", "name_regexp", b"name_regexp", "names", b"names"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["match_by", b"match_by"]) -> typing.Literal["name_regexp", "ids", "names"] | None: ...

global___CatalogAccessRuleMatcher = CatalogAccessRuleMatcher

@typing.final
class SchemaAccessRuleMatcher(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class SchemaNames(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ANY_FIELD_NUMBER: builtins.int
        @property
        def any(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            any: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["any", b"any"]) -> None: ...

    NAME_REGEXP_FIELD_NUMBER: builtins.int
    NAMES_FIELD_NUMBER: builtins.int
    name_regexp: builtins.str
    """Schema name regexp the rule is applied to."""
    @property
    def names(self) -> global___SchemaAccessRuleMatcher.SchemaNames:
        """Schema names the rule is applied to."""

    def __init__(
        self,
        *,
        name_regexp: builtins.str = ...,
        names: global___SchemaAccessRuleMatcher.SchemaNames | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["match_by", b"match_by", "name_regexp", b"name_regexp", "names", b"names"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["match_by", b"match_by", "name_regexp", b"name_regexp", "names", b"names"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["match_by", b"match_by"]) -> typing.Literal["name_regexp", "names"] | None: ...

global___SchemaAccessRuleMatcher = SchemaAccessRuleMatcher

@typing.final
class TableAccessRuleMatcher(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class TableNames(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ANY_FIELD_NUMBER: builtins.int
        @property
        def any(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            any: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["any", b"any"]) -> None: ...

    NAME_REGEXP_FIELD_NUMBER: builtins.int
    NAMES_FIELD_NUMBER: builtins.int
    name_regexp: builtins.str
    """Table name regexp the rule is applied to."""
    @property
    def names(self) -> global___TableAccessRuleMatcher.TableNames:
        """Table names the rule is applied to."""

    def __init__(
        self,
        *,
        name_regexp: builtins.str = ...,
        names: global___TableAccessRuleMatcher.TableNames | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["match_by", b"match_by", "name_regexp", b"name_regexp", "names", b"names"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["match_by", b"match_by", "name_regexp", b"name_regexp", "names", b"names"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["match_by", b"match_by"]) -> typing.Literal["name_regexp", "names"] | None: ...

global___TableAccessRuleMatcher = TableAccessRuleMatcher

@typing.final
class FunctionAccessRuleMatcher(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class FunctionNames(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ANY_FIELD_NUMBER: builtins.int
        @property
        def any(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            any: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["any", b"any"]) -> None: ...

    NAME_REGEXP_FIELD_NUMBER: builtins.int
    NAMES_FIELD_NUMBER: builtins.int
    name_regexp: builtins.str
    """Function name regexp the rule is applied to."""
    @property
    def names(self) -> global___FunctionAccessRuleMatcher.FunctionNames:
        """Function names the rule is applied to."""

    def __init__(
        self,
        *,
        name_regexp: builtins.str = ...,
        names: global___FunctionAccessRuleMatcher.FunctionNames | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["match_by", b"match_by", "name_regexp", b"name_regexp", "names", b"names"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["match_by", b"match_by", "name_regexp", b"name_regexp", "names", b"names"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["match_by", b"match_by"]) -> typing.Literal["name_regexp", "names"] | None: ...

global___FunctionAccessRuleMatcher = FunctionAccessRuleMatcher

@typing.final
class ProcedureAccessRuleMatcher(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ProcedureNames(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ANY_FIELD_NUMBER: builtins.int
        @property
        def any(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            any: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["any", b"any"]) -> None: ...

    NAME_REGEXP_FIELD_NUMBER: builtins.int
    NAMES_FIELD_NUMBER: builtins.int
    name_regexp: builtins.str
    """Procedure name regexp the rule is applied to."""
    @property
    def names(self) -> global___ProcedureAccessRuleMatcher.ProcedureNames:
        """Procedure names the rule is applied to."""

    def __init__(
        self,
        *,
        name_regexp: builtins.str = ...,
        names: global___ProcedureAccessRuleMatcher.ProcedureNames | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["match_by", b"match_by", "name_regexp", b"name_regexp", "names", b"names"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["match_by", b"match_by", "name_regexp", b"name_regexp", "names", b"names"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["match_by", b"match_by"]) -> typing.Literal["name_regexp", "names"] | None: ...

global___ProcedureAccessRuleMatcher = ProcedureAccessRuleMatcher

@typing.final
class PropertyAccessRuleMatcher(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class PropertyNames(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ANY_FIELD_NUMBER: builtins.int
        @property
        def any(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            any: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["any", b"any"]) -> None: ...

    NAME_REGEXP_FIELD_NUMBER: builtins.int
    NAMES_FIELD_NUMBER: builtins.int
    name_regexp: builtins.str
    """Property name regexp the rule is applied to."""
    @property
    def names(self) -> global___PropertyAccessRuleMatcher.PropertyNames:
        """Property names the rule is applied to."""

    def __init__(
        self,
        *,
        name_regexp: builtins.str = ...,
        names: global___PropertyAccessRuleMatcher.PropertyNames | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["match_by", b"match_by", "name_regexp", b"name_regexp", "names", b"names"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["match_by", b"match_by", "name_regexp", b"name_regexp", "names", b"names"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["match_by", b"match_by"]) -> typing.Literal["name_regexp", "names"] | None: ...

global___PropertyAccessRuleMatcher = PropertyAccessRuleMatcher

@typing.final
class CatalogAccessRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Permission:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PermissionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CatalogAccessRule._Permission.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PERMISSION_UNSPECIFIED: CatalogAccessRule._Permission.ValueType  # 0
        NONE: CatalogAccessRule._Permission.ValueType  # 1
        """Denies all operations on the catalog entities."""
        ALL: CatalogAccessRule._Permission.ValueType  # 2
        """Allows all operations on catalog entities."""
        READ_ONLY: CatalogAccessRule._Permission.ValueType  # 3
        """Allows only read operations on catalog entities."""

    class Permission(_Permission, metaclass=_PermissionEnumTypeWrapper): ...
    PERMISSION_UNSPECIFIED: CatalogAccessRule.Permission.ValueType  # 0
    NONE: CatalogAccessRule.Permission.ValueType  # 1
    """Denies all operations on the catalog entities."""
    ALL: CatalogAccessRule.Permission.ValueType  # 2
    """Allows all operations on catalog entities."""
    READ_ONLY: CatalogAccessRule.Permission.ValueType  # 3
    """Allows only read operations on catalog entities."""

    USERS_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    CATALOG_FIELD_NUMBER: builtins.int
    PERMISSION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    permission: global___CatalogAccessRule.Permission.ValueType
    """Permission granted by the rule."""
    description: builtins.str
    """Rule description."""
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IAM user IDs the rule is applied to."""

    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IAM group IDs the rule is applied to."""

    @property
    def catalog(self) -> global___CatalogAccessRuleMatcher:
        """Catalog matcher specifying what catalogs the rule is applied to."""

    def __init__(
        self,
        *,
        users: collections.abc.Iterable[builtins.str] | None = ...,
        groups: collections.abc.Iterable[builtins.str] | None = ...,
        catalog: global___CatalogAccessRuleMatcher | None = ...,
        permission: global___CatalogAccessRule.Permission.ValueType = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["catalog", b"catalog"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["catalog", b"catalog", "description", b"description", "groups", b"groups", "permission", b"permission", "users", b"users"]) -> None: ...

global___CatalogAccessRule = CatalogAccessRule

@typing.final
class SchemaAccessRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Owner:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _OwnerEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SchemaAccessRule._Owner.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        OWNER_UNSPECIFIED: SchemaAccessRule._Owner.ValueType  # 0
        NO: SchemaAccessRule._Owner.ValueType  # 1
        """User is not considered an owner of the schema."""
        YES: SchemaAccessRule._Owner.ValueType  # 2
        """User is considered an owner of the schema."""

    class Owner(_Owner, metaclass=_OwnerEnumTypeWrapper): ...
    OWNER_UNSPECIFIED: SchemaAccessRule.Owner.ValueType  # 0
    NO: SchemaAccessRule.Owner.ValueType  # 1
    """User is not considered an owner of the schema."""
    YES: SchemaAccessRule.Owner.ValueType  # 2
    """User is considered an owner of the schema."""

    USERS_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    CATALOG_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    owner: global___SchemaAccessRule.Owner.ValueType
    """Ownership granted by the rule."""
    description: builtins.str
    """Rule description."""
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IAM user IDs the rule is applied to."""

    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IAM group IDs the rule is applied to."""

    @property
    def catalog(self) -> global___CatalogAccessRuleMatcher:
        """Catalog matcher specifying what catalogs the rule is applied to."""

    @property
    def schema(self) -> global___SchemaAccessRuleMatcher:
        """Schema matcher specifying what schemas the rule is applied to."""

    def __init__(
        self,
        *,
        users: collections.abc.Iterable[builtins.str] | None = ...,
        groups: collections.abc.Iterable[builtins.str] | None = ...,
        catalog: global___CatalogAccessRuleMatcher | None = ...,
        schema: global___SchemaAccessRuleMatcher | None = ...,
        owner: global___SchemaAccessRule.Owner.ValueType = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["catalog", b"catalog", "schema", b"schema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["catalog", b"catalog", "description", b"description", "groups", b"groups", "owner", b"owner", "schema", b"schema", "users", b"users"]) -> None: ...

global___SchemaAccessRule = SchemaAccessRule

@typing.final
class TableAccessRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Privilege:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PrivilegeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TableAccessRule._Privilege.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PRIVILEGE_UNSPECIFIED: TableAccessRule._Privilege.ValueType  # 0
        SELECT: TableAccessRule._Privilege.ValueType  # 1
        """Allows SELECT statements on the table."""
        INSERT: TableAccessRule._Privilege.ValueType  # 2
        """Allows INSERT statements on the table."""
        DELETE: TableAccessRule._Privilege.ValueType  # 3
        """Allows DELETE statements on the table."""
        UPDATE: TableAccessRule._Privilege.ValueType  # 4
        """Allows UPDATE statements on the table."""
        OWNERSHIP: TableAccessRule._Privilege.ValueType  # 5
        """Allows CREATE, DROP, COMMENT ON and ALTER statements on the table."""
        GRANT_SELECT: TableAccessRule._Privilege.ValueType  # 6
        """Allows SELECT statements on the table while creating view."""

    class Privilege(_Privilege, metaclass=_PrivilegeEnumTypeWrapper): ...
    PRIVILEGE_UNSPECIFIED: TableAccessRule.Privilege.ValueType  # 0
    SELECT: TableAccessRule.Privilege.ValueType  # 1
    """Allows SELECT statements on the table."""
    INSERT: TableAccessRule.Privilege.ValueType  # 2
    """Allows INSERT statements on the table."""
    DELETE: TableAccessRule.Privilege.ValueType  # 3
    """Allows DELETE statements on the table."""
    UPDATE: TableAccessRule.Privilege.ValueType  # 4
    """Allows UPDATE statements on the table."""
    OWNERSHIP: TableAccessRule.Privilege.ValueType  # 5
    """Allows CREATE, DROP, COMMENT ON and ALTER statements on the table."""
    GRANT_SELECT: TableAccessRule.Privilege.ValueType  # 6
    """Allows SELECT statements on the table while creating view."""

    @typing.final
    class Column(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _AccessMode:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _AccessModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TableAccessRule.Column._AccessMode.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            ACCESS_MODE_UNSPECIFIED: TableAccessRule.Column._AccessMode.ValueType  # 0
            NONE: TableAccessRule.Column._AccessMode.ValueType  # 1
            """Access to column is denied."""
            ALL: TableAccessRule.Column._AccessMode.ValueType  # 2
            """Access to column is allowed."""

        class AccessMode(_AccessMode, metaclass=_AccessModeEnumTypeWrapper): ...
        ACCESS_MODE_UNSPECIFIED: TableAccessRule.Column.AccessMode.ValueType  # 0
        NONE: TableAccessRule.Column.AccessMode.ValueType  # 1
        """Access to column is denied."""
        ALL: TableAccessRule.Column.AccessMode.ValueType  # 2
        """Access to column is allowed."""

        NAME_FIELD_NUMBER: builtins.int
        ACCESS_FIELD_NUMBER: builtins.int
        MASK_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Column name."""
        access: global___TableAccessRule.Column.AccessMode.ValueType
        """Column access mode."""
        mask: builtins.str
        """SQL expression mask to evaluate instead of original column values.
        Mask should have the same type as original column.
        """
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            access: global___TableAccessRule.Column.AccessMode.ValueType = ...,
            mask: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["access", b"access", "mask", b"mask", "name", b"name"]) -> None: ...

    USERS_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    CATALOG_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    PRIVILEGES_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    filter: builtins.str
    """Boolean SQL expression to filter table rows for particular user."""
    description: builtins.str
    """Rule description."""
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IAM user IDs the rule is applied to."""

    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IAM group IDs the rule is applied to."""

    @property
    def catalog(self) -> global___CatalogAccessRuleMatcher:
        """Catalog matcher specifying what catalogs the rule is applied to."""

    @property
    def schema(self) -> global___SchemaAccessRuleMatcher:
        """Schema matcher specifying what schemas the rule is applied to."""

    @property
    def table(self) -> global___TableAccessRuleMatcher:
        """Table matcher specifying what tables the rule is applied to."""

    @property
    def privileges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___TableAccessRule.Privilege.ValueType]:
        """Permission granted by the rule."""

    @property
    def columns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TableAccessRule.Column]:
        """Column rules."""

    def __init__(
        self,
        *,
        users: collections.abc.Iterable[builtins.str] | None = ...,
        groups: collections.abc.Iterable[builtins.str] | None = ...,
        catalog: global___CatalogAccessRuleMatcher | None = ...,
        schema: global___SchemaAccessRuleMatcher | None = ...,
        table: global___TableAccessRuleMatcher | None = ...,
        privileges: collections.abc.Iterable[global___TableAccessRule.Privilege.ValueType] | None = ...,
        columns: collections.abc.Iterable[global___TableAccessRule.Column] | None = ...,
        filter: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["catalog", b"catalog", "schema", b"schema", "table", b"table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["catalog", b"catalog", "columns", b"columns", "description", b"description", "filter", b"filter", "groups", b"groups", "privileges", b"privileges", "schema", b"schema", "table", b"table", "users", b"users"]) -> None: ...

global___TableAccessRule = TableAccessRule

@typing.final
class FunctionAccessRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Privilege:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PrivilegeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FunctionAccessRule._Privilege.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PRIVILEGE_UNSPECIFIED: FunctionAccessRule._Privilege.ValueType  # 0
        EXECUTE: FunctionAccessRule._Privilege.ValueType  # 1
        """Allows to execute the function."""
        GRANT_EXECUTE: FunctionAccessRule._Privilege.ValueType  # 2
        """Allows to use the function while view creation."""
        OWNERSHIP: FunctionAccessRule._Privilege.ValueType  # 3
        """Allows to CREATE and DROP the function."""

    class Privilege(_Privilege, metaclass=_PrivilegeEnumTypeWrapper): ...
    PRIVILEGE_UNSPECIFIED: FunctionAccessRule.Privilege.ValueType  # 0
    EXECUTE: FunctionAccessRule.Privilege.ValueType  # 1
    """Allows to execute the function."""
    GRANT_EXECUTE: FunctionAccessRule.Privilege.ValueType  # 2
    """Allows to use the function while view creation."""
    OWNERSHIP: FunctionAccessRule.Privilege.ValueType  # 3
    """Allows to CREATE and DROP the function."""

    USERS_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    CATALOG_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    FUNCTION_FIELD_NUMBER: builtins.int
    PRIVILEGES_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    description: builtins.str
    """Rule description."""
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IAM user IDs the rule is applied to."""

    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IAM group IDs the rule is applied to."""

    @property
    def catalog(self) -> global___CatalogAccessRuleMatcher:
        """Catalog matcher specifying what catalogs the rule is applied to."""

    @property
    def schema(self) -> global___SchemaAccessRuleMatcher:
        """Schema matcher specifying what schema the rule is applied to."""

    @property
    def function(self) -> global___FunctionAccessRuleMatcher:
        """Function matcher specifying what functions the rule is applied to."""

    @property
    def privileges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___FunctionAccessRule.Privilege.ValueType]:
        """Privileges granted by the rule."""

    def __init__(
        self,
        *,
        users: collections.abc.Iterable[builtins.str] | None = ...,
        groups: collections.abc.Iterable[builtins.str] | None = ...,
        catalog: global___CatalogAccessRuleMatcher | None = ...,
        schema: global___SchemaAccessRuleMatcher | None = ...,
        function: global___FunctionAccessRuleMatcher | None = ...,
        privileges: collections.abc.Iterable[global___FunctionAccessRule.Privilege.ValueType] | None = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["catalog", b"catalog", "function", b"function", "schema", b"schema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["catalog", b"catalog", "description", b"description", "function", b"function", "groups", b"groups", "privileges", b"privileges", "schema", b"schema", "users", b"users"]) -> None: ...

global___FunctionAccessRule = FunctionAccessRule

@typing.final
class ProcedureAccessRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Privilege:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PrivilegeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ProcedureAccessRule._Privilege.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PRIVILEGE_UNSPECIFIED: ProcedureAccessRule._Privilege.ValueType  # 0
        EXECUTE: ProcedureAccessRule._Privilege.ValueType  # 1
        """Allows to execute the procedure."""

    class Privilege(_Privilege, metaclass=_PrivilegeEnumTypeWrapper): ...
    PRIVILEGE_UNSPECIFIED: ProcedureAccessRule.Privilege.ValueType  # 0
    EXECUTE: ProcedureAccessRule.Privilege.ValueType  # 1
    """Allows to execute the procedure."""

    USERS_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    CATALOG_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    PROCEDURE_FIELD_NUMBER: builtins.int
    PRIVILEGES_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    description: builtins.str
    """Rule description."""
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IAM user IDs the rule is applied to."""

    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IAM group IDs the rule is applied to."""

    @property
    def catalog(self) -> global___CatalogAccessRuleMatcher:
        """Catalog matcher specifying what catalogs the rule is applied to."""

    @property
    def schema(self) -> global___SchemaAccessRuleMatcher:
        """Schema matcher specifying what schema the rule is applied to."""

    @property
    def procedure(self) -> global___ProcedureAccessRuleMatcher:
        """Procedure matcher specifying what functions the rule is applied to."""

    @property
    def privileges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___ProcedureAccessRule.Privilege.ValueType]:
        """Privileges granted by the rule."""

    def __init__(
        self,
        *,
        users: collections.abc.Iterable[builtins.str] | None = ...,
        groups: collections.abc.Iterable[builtins.str] | None = ...,
        catalog: global___CatalogAccessRuleMatcher | None = ...,
        schema: global___SchemaAccessRuleMatcher | None = ...,
        procedure: global___ProcedureAccessRuleMatcher | None = ...,
        privileges: collections.abc.Iterable[global___ProcedureAccessRule.Privilege.ValueType] | None = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["catalog", b"catalog", "procedure", b"procedure", "schema", b"schema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["catalog", b"catalog", "description", b"description", "groups", b"groups", "privileges", b"privileges", "procedure", b"procedure", "schema", b"schema", "users", b"users"]) -> None: ...

global___ProcedureAccessRule = ProcedureAccessRule

@typing.final
class QueryAccessRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Privilege:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PrivilegeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[QueryAccessRule._Privilege.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PRIVILEGE_UNSPECIFIED: QueryAccessRule._Privilege.ValueType  # 0
        VIEW: QueryAccessRule._Privilege.ValueType  # 1
        """Allows to view the query."""
        EXECUTE: QueryAccessRule._Privilege.ValueType  # 2
        """Allows to execute the query."""
        KILL: QueryAccessRule._Privilege.ValueType  # 3
        """Allows to kill the query."""

    class Privilege(_Privilege, metaclass=_PrivilegeEnumTypeWrapper): ...
    PRIVILEGE_UNSPECIFIED: QueryAccessRule.Privilege.ValueType  # 0
    VIEW: QueryAccessRule.Privilege.ValueType  # 1
    """Allows to view the query."""
    EXECUTE: QueryAccessRule.Privilege.ValueType  # 2
    """Allows to execute the query."""
    KILL: QueryAccessRule.Privilege.ValueType  # 3
    """Allows to kill the query."""

    USERS_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    QUERY_OWNERS_FIELD_NUMBER: builtins.int
    PRIVILEGES_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    description: builtins.str
    """Rule description."""
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IAM user IDs the rule is applied to."""

    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IAM group IDs the rule is applied to."""

    @property
    def query_owners(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Owners of queries the rule is applied to.
        Cannot be combined with EXECUTE privilege.
        """

    @property
    def privileges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___QueryAccessRule.Privilege.ValueType]:
        """Privileges granted by the user."""

    def __init__(
        self,
        *,
        users: collections.abc.Iterable[builtins.str] | None = ...,
        groups: collections.abc.Iterable[builtins.str] | None = ...,
        query_owners: collections.abc.Iterable[builtins.str] | None = ...,
        privileges: collections.abc.Iterable[global___QueryAccessRule.Privilege.ValueType] | None = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "groups", b"groups", "privileges", b"privileges", "query_owners", b"query_owners", "users", b"users"]) -> None: ...

global___QueryAccessRule = QueryAccessRule

@typing.final
class SystemSessionPropertyAccessRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Allow:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _AllowEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SystemSessionPropertyAccessRule._Allow.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ALLOW_UNSPECIFIED: SystemSessionPropertyAccessRule._Allow.ValueType  # 0
        NO: SystemSessionPropertyAccessRule._Allow.ValueType  # 1
        """Denies setting the system session property."""
        YES: SystemSessionPropertyAccessRule._Allow.ValueType  # 2
        """Allows to set the system session property."""

    class Allow(_Allow, metaclass=_AllowEnumTypeWrapper): ...
    ALLOW_UNSPECIFIED: SystemSessionPropertyAccessRule.Allow.ValueType  # 0
    NO: SystemSessionPropertyAccessRule.Allow.ValueType  # 1
    """Denies setting the system session property."""
    YES: SystemSessionPropertyAccessRule.Allow.ValueType  # 2
    """Allows to set the system session property."""

    USERS_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    PROPERTY_FIELD_NUMBER: builtins.int
    ALLOW_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    allow: global___SystemSessionPropertyAccessRule.Allow.ValueType
    """Whether the rule allows setting the property."""
    description: builtins.str
    """Rule description."""
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IAM user IDs the rule is applied to."""

    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IAM group IDs the rule is applied to."""

    @property
    def property(self) -> global___PropertyAccessRuleMatcher:
        """Property matcher specifying what properties the rule is applied to."""

    def __init__(
        self,
        *,
        users: collections.abc.Iterable[builtins.str] | None = ...,
        groups: collections.abc.Iterable[builtins.str] | None = ...,
        property: global___PropertyAccessRuleMatcher | None = ...,
        allow: global___SystemSessionPropertyAccessRule.Allow.ValueType = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["property", b"property"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allow", b"allow", "description", b"description", "groups", b"groups", "property", b"property", "users", b"users"]) -> None: ...

global___SystemSessionPropertyAccessRule = SystemSessionPropertyAccessRule

@typing.final
class CatalogSessionPropertyAccessRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Allow:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _AllowEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CatalogSessionPropertyAccessRule._Allow.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ALLOW_UNSPECIFIED: CatalogSessionPropertyAccessRule._Allow.ValueType  # 0
        NO: CatalogSessionPropertyAccessRule._Allow.ValueType  # 1
        """Denies setting the catalog session property."""
        YES: CatalogSessionPropertyAccessRule._Allow.ValueType  # 2
        """Allows to set the catalog session property."""

    class Allow(_Allow, metaclass=_AllowEnumTypeWrapper): ...
    ALLOW_UNSPECIFIED: CatalogSessionPropertyAccessRule.Allow.ValueType  # 0
    NO: CatalogSessionPropertyAccessRule.Allow.ValueType  # 1
    """Denies setting the catalog session property."""
    YES: CatalogSessionPropertyAccessRule.Allow.ValueType  # 2
    """Allows to set the catalog session property."""

    USERS_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    CATALOG_FIELD_NUMBER: builtins.int
    PROPERTY_FIELD_NUMBER: builtins.int
    ALLOW_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    allow: global___CatalogSessionPropertyAccessRule.Allow.ValueType
    """Whether the rule allows setting the property."""
    description: builtins.str
    """Rule description."""
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IAM user IDs the rule is applied to."""

    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IAM group IDs the rule is applied to."""

    @property
    def catalog(self) -> global___CatalogAccessRuleMatcher:
        """Catalog matcher specifying what catalogs the rule is applied to."""

    @property
    def property(self) -> global___PropertyAccessRuleMatcher:
        """Property matcher specifying what properties the rule is applied to."""

    def __init__(
        self,
        *,
        users: collections.abc.Iterable[builtins.str] | None = ...,
        groups: collections.abc.Iterable[builtins.str] | None = ...,
        catalog: global___CatalogAccessRuleMatcher | None = ...,
        property: global___PropertyAccessRuleMatcher | None = ...,
        allow: global___CatalogSessionPropertyAccessRule.Allow.ValueType = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["catalog", b"catalog", "property", b"property"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allow", b"allow", "catalog", b"catalog", "description", b"description", "groups", b"groups", "property", b"property", "users", b"users"]) -> None: ...

global___CatalogSessionPropertyAccessRule = CatalogSessionPropertyAccessRule



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.smartwebsecurity.v1.security_profile_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class AdvancedRateLimiterProfile(google.protobuf.message.Message):
    """A AdvancedRateLimiterProfile (ARL) resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ADVANCED_RATE_LIMITER_RULES_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the ARL profile."""
    folder_id: builtins.str
    """ID of the folder that the ARL profile belongs to."""
    name: builtins.str
    """Name of the ARL profile. The name is unique within the folder. 1-50 characters long."""
    description: builtins.str
    """Optional description of the ARL profile."""
    cloud_id: builtins.str
    """ID of the cloud that the ARL profile belongs to."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels as `` key:value `` pairs. Maximum of 64 per resource."""

    @property
    def advanced_rate_limiter_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AdvancedRateLimiterRule]:
        """List of rules."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        advanced_rate_limiter_rules: collections.abc.Iterable[global___AdvancedRateLimiterRule] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        cloud_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["advanced_rate_limiter_rules", b"advanced_rate_limiter_rules", "cloud_id", b"cloud_id", "created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name"]) -> None: ...

global___AdvancedRateLimiterProfile = AdvancedRateLimiterProfile

@typing.final
class AdvancedRateLimiterRule(google.protobuf.message.Message):
    """A AdvancedRateLimiterRule object, see [Rules](/docs/smartwebsecurity/concepts/arl#traffic-conditions)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Action:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdvancedRateLimiterRule._Action.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ACTION_UNSPECIFIED: AdvancedRateLimiterRule._Action.ValueType  # 0
        DENY: AdvancedRateLimiterRule._Action.ValueType  # 1
        """Deny request."""

    class Action(_Action, metaclass=_ActionEnumTypeWrapper):
        """Type of action to perform if this rule matched."""

    ACTION_UNSPECIFIED: AdvancedRateLimiterRule.Action.ValueType  # 0
    DENY: AdvancedRateLimiterRule.Action.ValueType  # 1
    """Deny request."""

    @typing.final
    class StaticQuota(google.protobuf.message.Message):
        """StaticQuota object."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ACTION_FIELD_NUMBER: builtins.int
        CONDITION_FIELD_NUMBER: builtins.int
        LIMIT_FIELD_NUMBER: builtins.int
        PERIOD_FIELD_NUMBER: builtins.int
        action: global___AdvancedRateLimiterRule.Action.ValueType
        """Action in case of exceeding this quota."""
        limit: builtins.int
        """Desired maximum number of requests per period.
        Enter an integer within the range of 1 and 9999999999999.
        """
        period: builtins.int
        """Period of time in seconds."""
        @property
        def condition(self) -> yandex.cloud.smartwebsecurity.v1.security_profile_pb2.Condition:
            """The condition for matching the quota."""

        def __init__(
            self,
            *,
            action: global___AdvancedRateLimiterRule.Action.ValueType = ...,
            condition: yandex.cloud.smartwebsecurity.v1.security_profile_pb2.Condition | None = ...,
            limit: builtins.int = ...,
            period: builtins.int = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["condition", b"condition"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "condition", b"condition", "limit", b"limit", "period", b"period"]) -> None: ...

    @typing.final
    class DynamicQuota(google.protobuf.message.Message):
        """DynamicQuota object."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class Characteristic(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            @typing.final
            class SimpleCharacteristic(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                class _Type:
                    ValueType = typing.NewType("ValueType", builtins.int)
                    V: typing_extensions.TypeAlias = ValueType

                class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristic._Type.ValueType], builtins.type):
                    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                    TYPE_UNSPECIFIED: AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristic._Type.ValueType  # 0
                    REQUEST_PATH: AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristic._Type.ValueType  # 1
                    """HTTP Request path."""
                    HTTP_METHOD: AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristic._Type.ValueType  # 2
                    """HTTP Method."""
                    IP: AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristic._Type.ValueType  # 3
                    """IP address."""
                    GEO: AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristic._Type.ValueType  # 4
                    """Region."""
                    HOST: AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristic._Type.ValueType  # 5
                    """Host."""

                class Type(_Type, metaclass=_TypeEnumTypeWrapper):
                    """Type of simple characteristic."""

                TYPE_UNSPECIFIED: AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristic.Type.ValueType  # 0
                REQUEST_PATH: AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristic.Type.ValueType  # 1
                """HTTP Request path."""
                HTTP_METHOD: AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristic.Type.ValueType  # 2
                """HTTP Method."""
                IP: AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristic.Type.ValueType  # 3
                """IP address."""
                GEO: AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristic.Type.ValueType  # 4
                """Region."""
                HOST: AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristic.Type.ValueType  # 5
                """Host."""

                TYPE_FIELD_NUMBER: builtins.int
                type: global___AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristic.Type.ValueType
                """Type of simple characteristic."""
                def __init__(
                    self,
                    *,
                    type: global___AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristic.Type.ValueType = ...,
                ) -> None: ...
                def ClearField(self, field_name: typing.Literal["type", b"type"]) -> None: ...

            @typing.final
            class KeyCharacteristic(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                class _Type:
                    ValueType = typing.NewType("ValueType", builtins.int)
                    V: typing_extensions.TypeAlias = ValueType

                class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdvancedRateLimiterRule.DynamicQuota.Characteristic.KeyCharacteristic._Type.ValueType], builtins.type):
                    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                    TYPE_UNSPECIFIED: AdvancedRateLimiterRule.DynamicQuota.Characteristic.KeyCharacteristic._Type.ValueType  # 0
                    COOKIE_KEY: AdvancedRateLimiterRule.DynamicQuota.Characteristic.KeyCharacteristic._Type.ValueType  # 1
                    """HTTP cookie key."""
                    HEADER_KEY: AdvancedRateLimiterRule.DynamicQuota.Characteristic.KeyCharacteristic._Type.ValueType  # 2
                    """HTTP header key."""
                    QUERY_KEY: AdvancedRateLimiterRule.DynamicQuota.Characteristic.KeyCharacteristic._Type.ValueType  # 3
                    """Query params key."""

                class Type(_Type, metaclass=_TypeEnumTypeWrapper):
                    """Type of key characteristic."""

                TYPE_UNSPECIFIED: AdvancedRateLimiterRule.DynamicQuota.Characteristic.KeyCharacteristic.Type.ValueType  # 0
                COOKIE_KEY: AdvancedRateLimiterRule.DynamicQuota.Characteristic.KeyCharacteristic.Type.ValueType  # 1
                """HTTP cookie key."""
                HEADER_KEY: AdvancedRateLimiterRule.DynamicQuota.Characteristic.KeyCharacteristic.Type.ValueType  # 2
                """HTTP header key."""
                QUERY_KEY: AdvancedRateLimiterRule.DynamicQuota.Characteristic.KeyCharacteristic.Type.ValueType  # 3
                """Query params key."""

                TYPE_FIELD_NUMBER: builtins.int
                VALUE_FIELD_NUMBER: builtins.int
                type: global___AdvancedRateLimiterRule.DynamicQuota.Characteristic.KeyCharacteristic.Type.ValueType
                """Type of key characteristic."""
                value: builtins.str
                """String value of the key."""
                def __init__(
                    self,
                    *,
                    type: global___AdvancedRateLimiterRule.DynamicQuota.Characteristic.KeyCharacteristic.Type.ValueType = ...,
                    value: builtins.str = ...,
                ) -> None: ...
                def ClearField(self, field_name: typing.Literal["type", b"type", "value", b"value"]) -> None: ...

            SIMPLE_CHARACTERISTIC_FIELD_NUMBER: builtins.int
            KEY_CHARACTERISTIC_FIELD_NUMBER: builtins.int
            CASE_INSENSITIVE_FIELD_NUMBER: builtins.int
            case_insensitive: builtins.bool
            """Determines case-sensitive or case-insensitive keys matching."""
            @property
            def simple_characteristic(self) -> global___AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristic:
                """Characteristic automatically based on the Request path, HTTP method, IP address, Region, and Host attributes.
                See [Rules](/docs/smartwebsecurity/concepts/arl#requests-counting) for more details.
                """

            @property
            def key_characteristic(self) -> global___AdvancedRateLimiterRule.DynamicQuota.Characteristic.KeyCharacteristic:
                """Characteristic based on key match in the Query params, HTTP header, and HTTP cookie attributes.
                See [Rules](/docs/smartwebsecurity/concepts/arl#requests-counting) for more details.
                """

            def __init__(
                self,
                *,
                simple_characteristic: global___AdvancedRateLimiterRule.DynamicQuota.Characteristic.SimpleCharacteristic | None = ...,
                key_characteristic: global___AdvancedRateLimiterRule.DynamicQuota.Characteristic.KeyCharacteristic | None = ...,
                case_insensitive: builtins.bool = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["characteristic_specifier", b"characteristic_specifier", "key_characteristic", b"key_characteristic", "simple_characteristic", b"simple_characteristic"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["case_insensitive", b"case_insensitive", "characteristic_specifier", b"characteristic_specifier", "key_characteristic", b"key_characteristic", "simple_characteristic", b"simple_characteristic"]) -> None: ...
            def WhichOneof(self, oneof_group: typing.Literal["characteristic_specifier", b"characteristic_specifier"]) -> typing.Literal["simple_characteristic", "key_characteristic"] | None: ...

        ACTION_FIELD_NUMBER: builtins.int
        CONDITION_FIELD_NUMBER: builtins.int
        LIMIT_FIELD_NUMBER: builtins.int
        PERIOD_FIELD_NUMBER: builtins.int
        CHARACTERISTICS_FIELD_NUMBER: builtins.int
        action: global___AdvancedRateLimiterRule.Action.ValueType
        """Action in case of exceeding this quota."""
        limit: builtins.int
        """Desired maximum number of requests per period.
        Enter an integer within the range of 1 and 9999999999999.
        """
        period: builtins.int
        """Period of time in seconds."""
        @property
        def condition(self) -> yandex.cloud.smartwebsecurity.v1.security_profile_pb2.Condition:
            """The condition for matching the quota."""

        @property
        def characteristics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AdvancedRateLimiterRule.DynamicQuota.Characteristic]:
            """List of characteristics."""

        def __init__(
            self,
            *,
            action: global___AdvancedRateLimiterRule.Action.ValueType = ...,
            condition: yandex.cloud.smartwebsecurity.v1.security_profile_pb2.Condition | None = ...,
            limit: builtins.int = ...,
            period: builtins.int = ...,
            characteristics: collections.abc.Iterable[global___AdvancedRateLimiterRule.DynamicQuota.Characteristic] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["condition", b"condition"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "characteristics", b"characteristics", "condition", b"condition", "limit", b"limit", "period", b"period"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DRY_RUN_FIELD_NUMBER: builtins.int
    STATIC_QUOTA_FIELD_NUMBER: builtins.int
    DYNAMIC_QUOTA_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the rule. The name is unique within the ARL profile. 1-50 characters long."""
    priority: builtins.int
    """Determines the priority in case there are several matched rules.
    Enter an integer within the range of 1 and 999999.
    The rule priority must be unique within the entire ARL profile.
    A lower numeric value means a higher priority.
    """
    description: builtins.str
    """Optional description of the rule. 0-512 characters long."""
    dry_run: builtins.bool
    """This allows you to evaluate backend capabilities and find the optimum limit values.
    Requests will not be blocked in this mode.
    """
    @property
    def static_quota(self) -> global___AdvancedRateLimiterRule.StaticQuota:
        """Static quota. Counting each request individually."""

    @property
    def dynamic_quota(self) -> global___AdvancedRateLimiterRule.DynamicQuota:
        """Dynamic quota. Grouping requests by a certain attribute and limiting the number of groups."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        priority: builtins.int = ...,
        description: builtins.str = ...,
        dry_run: builtins.bool = ...,
        static_quota: global___AdvancedRateLimiterRule.StaticQuota | None = ...,
        dynamic_quota: global___AdvancedRateLimiterRule.DynamicQuota | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["dynamic_quota", b"dynamic_quota", "rule_specifier", b"rule_specifier", "static_quota", b"static_quota"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "dry_run", b"dry_run", "dynamic_quota", b"dynamic_quota", "name", b"name", "priority", b"priority", "rule_specifier", b"rule_specifier", "static_quota", b"static_quota"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["rule_specifier", b"rule_specifier"]) -> typing.Literal["static_quota", "dynamic_quota"] | None: ...

global___AdvancedRateLimiterRule = AdvancedRateLimiterRule



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/video/v1/playlist.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/video/v1/playlist.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$yandex/cloud/video/v1/playlist.proto\x12\x15yandex.cloud.video.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\x81\x02\n\x08Playlist\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x32\n\x05items\x18\x05 \x03(\x0b\x32#.yandex.cloud.video.v1.PlaylistItem\x12\x17\n\x0fstyle_preset_id\x18\x06 \x01(\t\x12.\n\ncreated_at\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.TimestampJ\x04\x08\x07\x10\x64\"u\n\x0cPlaylistItem\x12\x1c\n\x08video_id\x18\x64 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1e\n\nepisode_id\x18\x65 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1b\n\x08position\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100B\x04\n\x02idJ\x04\x08\x02\x10\x64\x42\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.playlist_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_PLAYLISTITEM'].fields_by_name['video_id']._loaded_options = None
  _globals['_PLAYLISTITEM'].fields_by_name['video_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_PLAYLISTITEM'].fields_by_name['episode_id']._loaded_options = None
  _globals['_PLAYLISTITEM'].fields_by_name['episode_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_PLAYLISTITEM'].fields_by_name['position']._loaded_options = None
  _globals['_PLAYLISTITEM'].fields_by_name['position']._serialized_options = b'\372\3071\0050-100'
  _globals['_PLAYLIST']._serialized_start=128
  _globals['_PLAYLIST']._serialized_end=385
  _globals['_PLAYLISTITEM']._serialized_start=387
  _globals['_PLAYLISTITEM']._serialized_end=504
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import google.type.timeofday_pb2
import sys
import typing
import yandex.cloud.mdb.mysql.v1.config.mysql5_7_pb2
import yandex.cloud.mdb.mysql.v1.config.mysql8_0_pb2
import yandex.cloud.mdb.mysql.v1.maintenance_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Cluster(google.protobuf.message.Message):
    """An object that represents MySQL cluster.

    See [the documentation](/docs/managed-mysql/concepts) for details.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Environment:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EnvironmentEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Environment.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ENVIRONMENT_UNSPECIFIED: Cluster._Environment.ValueType  # 0
        PRODUCTION: Cluster._Environment.ValueType  # 1
        """Environment for stable versions of your apps.
        A conservative update policy is in effect: only bug fixes are applied during regular maintenance.
        """
        PRESTABLE: Cluster._Environment.ValueType  # 2
        """Environment for testing, including the Managed Service for MySQL itself.
        This environment gets new features, improvements, and bug fixes in the first place, compared to the production environment.
        However, not every update ensures backward compatibility.
        """

    class Environment(_Environment, metaclass=_EnvironmentEnumTypeWrapper): ...
    ENVIRONMENT_UNSPECIFIED: Cluster.Environment.ValueType  # 0
    PRODUCTION: Cluster.Environment.ValueType  # 1
    """Environment for stable versions of your apps.
    A conservative update policy is in effect: only bug fixes are applied during regular maintenance.
    """
    PRESTABLE: Cluster.Environment.ValueType  # 2
    """Environment for testing, including the Managed Service for MySQL itself.
    This environment gets new features, improvements, and bug fixes in the first place, compared to the production environment.
    However, not every update ensures backward compatibility.
    """

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Cluster._Health.ValueType  # 0
        """Health of the cluster is unknown ([Host.health] for every host in the cluster is `UNKNOWN`)."""
        ALIVE: Cluster._Health.ValueType  # 1
        """Cluster is alive and well ([Host.health] for every host in the cluster is `ALIVE`)."""
        DEAD: Cluster._Health.ValueType  # 2
        """Cluster is inoperable ([Host.health] for every host in the cluster is `DEAD`)."""
        DEGRADED: Cluster._Health.ValueType  # 3
        """Cluster is degraded ([Host.health] for at least one host in the cluster is not `ALIVE`)."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Cluster.Health.ValueType  # 0
    """Health of the cluster is unknown ([Host.health] for every host in the cluster is `UNKNOWN`)."""
    ALIVE: Cluster.Health.ValueType  # 1
    """Cluster is alive and well ([Host.health] for every host in the cluster is `ALIVE`)."""
    DEAD: Cluster.Health.ValueType  # 2
    """Cluster is inoperable ([Host.health] for every host in the cluster is `DEAD`)."""
    DEGRADED: Cluster.Health.ValueType  # 3
    """Cluster is degraded ([Host.health] for at least one host in the cluster is not `ALIVE`)."""

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNKNOWN: Cluster._Status.ValueType  # 0
        """Cluster state is unknown."""
        CREATING: Cluster._Status.ValueType  # 1
        """Cluster is being created."""
        RUNNING: Cluster._Status.ValueType  # 2
        """Cluster is running normally."""
        ERROR: Cluster._Status.ValueType  # 3
        """Cluster encountered a problem and cannot operate."""
        UPDATING: Cluster._Status.ValueType  # 4
        """Cluster is being updated."""
        STOPPING: Cluster._Status.ValueType  # 5
        """Cluster is stopping."""
        STOPPED: Cluster._Status.ValueType  # 6
        """Cluster is stopped."""
        STARTING: Cluster._Status.ValueType  # 7
        """Cluster is starting."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNKNOWN: Cluster.Status.ValueType  # 0
    """Cluster state is unknown."""
    CREATING: Cluster.Status.ValueType  # 1
    """Cluster is being created."""
    RUNNING: Cluster.Status.ValueType  # 2
    """Cluster is running normally."""
    ERROR: Cluster.Status.ValueType  # 3
    """Cluster encountered a problem and cannot operate."""
    UPDATING: Cluster.Status.ValueType  # 4
    """Cluster is being updated."""
    STOPPING: Cluster.Status.ValueType  # 5
    """Cluster is stopping."""
    STOPPED: Cluster.Status.ValueType  # 6
    """Cluster is stopped."""
    STARTING: Cluster.Status.ValueType  # 7
    """Cluster is starting."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    MONITORING_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    PLANNED_OPERATION_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    HOST_GROUP_IDS_FIELD_NUMBER: builtins.int
    DISK_ENCRYPTION_KEY_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the cluster.

    This ID is assigned by the platform at the time of creation.
    """
    folder_id: builtins.str
    """ID of the folder that the cluster belongs to."""
    name: builtins.str
    """Name of the cluster."""
    description: builtins.str
    """Description of the cluster."""
    environment: global___Cluster.Environment.ValueType
    """Deployment environment of the MySQL cluster."""
    network_id: builtins.str
    """ID of the network that the cluster belongs to."""
    health: global___Cluster.Health.ValueType
    """Aggregated health of the cluster."""
    status: global___Cluster.Status.ValueType
    """Current state of the cluster."""
    deletion_protection: builtins.bool
    """This option prevents unintended deletion of the cluster."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp of the cluster."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the cluster as `key:value` pairs."""

    @property
    def monitoring(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Monitoring]:
        """Monitoring systems data that is relevant to the cluster."""

    @property
    def config(self) -> global___ClusterConfig:
        """Configuration of the cluster."""

    @property
    def maintenance_window(self) -> yandex.cloud.mdb.mysql.v1.maintenance_pb2.MaintenanceWindow:
        """Maintenance window settings for the cluster."""

    @property
    def planned_operation(self) -> yandex.cloud.mdb.mysql.v1.maintenance_pb2.MaintenanceOperation:
        """Planned maintenance operation to be started for the cluster within the nearest [maintenance_window]."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Effective list of security group IDs applied to the cluster."""

    @property
    def host_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Host groups hosting VMs of the cluster."""

    @property
    def disk_encryption_key_id(self) -> google.protobuf.wrappers_pb2.StringValue:
        """ID of the key to encrypt cluster disks."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        environment: global___Cluster.Environment.ValueType = ...,
        monitoring: collections.abc.Iterable[global___Monitoring] | None = ...,
        config: global___ClusterConfig | None = ...,
        network_id: builtins.str = ...,
        health: global___Cluster.Health.ValueType = ...,
        status: global___Cluster.Status.ValueType = ...,
        maintenance_window: yandex.cloud.mdb.mysql.v1.maintenance_pb2.MaintenanceWindow | None = ...,
        planned_operation: yandex.cloud.mdb.mysql.v1.maintenance_pb2.MaintenanceOperation | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        host_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        disk_encryption_key_id: google.protobuf.wrappers_pb2.StringValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at", "disk_encryption_key_id", b"disk_encryption_key_id", "maintenance_window", b"maintenance_window", "planned_operation", b"planned_operation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "disk_encryption_key_id", b"disk_encryption_key_id", "environment", b"environment", "folder_id", b"folder_id", "health", b"health", "host_group_ids", b"host_group_ids", "id", b"id", "labels", b"labels", "maintenance_window", b"maintenance_window", "monitoring", b"monitoring", "name", b"name", "network_id", b"network_id", "planned_operation", b"planned_operation", "security_group_ids", b"security_group_ids", "status", b"status"]) -> None: ...

global___Cluster = Cluster

@typing.final
class Monitoring(google.protobuf.message.Message):
    """Cluster-related monitoring system data."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the monitoring system."""
    description: builtins.str
    """Description of the monitoring system."""
    link: builtins.str
    """Link to the monitoring system charts for the cluster."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "link", b"link", "name", b"name"]) -> None: ...

global___Monitoring = Monitoring

@typing.final
class ClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    MYSQL_CONFIG_5_7_FIELD_NUMBER: builtins.int
    MYSQL_CONFIG_8_0_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    BACKUP_WINDOW_START_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    PERFORMANCE_DIAGNOSTICS_FIELD_NUMBER: builtins.int
    BACKUP_RETAIN_PERIOD_DAYS_FIELD_NUMBER: builtins.int
    DISK_SIZE_AUTOSCALING_FIELD_NUMBER: builtins.int
    version: builtins.str
    """Version of MySQL used in the cluster."""
    @property
    def mysql_config_5_7(self) -> yandex.cloud.mdb.mysql.v1.config.mysql5_7_pb2.MysqlConfigSet5_7:
        """Configuration of a MySQL 5.7 server."""

    @property
    def mysql_config_8_0(self) -> yandex.cloud.mdb.mysql.v1.config.mysql8_0_pb2.MysqlConfigSet8_0:
        """Configuration of a MySQL 8.0 server."""

    @property
    def resources(self) -> global___Resources:
        """Resource preset for the cluster hosts."""

    @property
    def backup_window_start(self) -> google.type.timeofday_pb2.TimeOfDay:
        """Time to start the daily backup, in the UTC timezone."""

    @property
    def access(self) -> global___Access:
        """Access policy for external services."""

    @property
    def performance_diagnostics(self) -> global___PerformanceDiagnostics:
        """Configuration of the performance diagnostics service."""

    @property
    def backup_retain_period_days(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Retention policy of automated backups."""

    @property
    def disk_size_autoscaling(self) -> global___DiskSizeAutoscaling:
        """Disk size autoscaling"""

    def __init__(
        self,
        *,
        version: builtins.str = ...,
        mysql_config_5_7: yandex.cloud.mdb.mysql.v1.config.mysql5_7_pb2.MysqlConfigSet5_7 | None = ...,
        mysql_config_8_0: yandex.cloud.mdb.mysql.v1.config.mysql8_0_pb2.MysqlConfigSet8_0 | None = ...,
        resources: global___Resources | None = ...,
        backup_window_start: google.type.timeofday_pb2.TimeOfDay | None = ...,
        access: global___Access | None = ...,
        performance_diagnostics: global___PerformanceDiagnostics | None = ...,
        backup_retain_period_days: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        disk_size_autoscaling: global___DiskSizeAutoscaling | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access", b"access", "backup_retain_period_days", b"backup_retain_period_days", "backup_window_start", b"backup_window_start", "disk_size_autoscaling", b"disk_size_autoscaling", "mysql_config", b"mysql_config", "mysql_config_5_7", b"mysql_config_5_7", "mysql_config_8_0", b"mysql_config_8_0", "performance_diagnostics", b"performance_diagnostics", "resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access", b"access", "backup_retain_period_days", b"backup_retain_period_days", "backup_window_start", b"backup_window_start", "disk_size_autoscaling", b"disk_size_autoscaling", "mysql_config", b"mysql_config", "mysql_config_5_7", b"mysql_config_5_7", "mysql_config_8_0", b"mysql_config_8_0", "performance_diagnostics", b"performance_diagnostics", "resources", b"resources", "version", b"version"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["mysql_config", b"mysql_config"]) -> typing.Literal["mysql_config_5_7", "mysql_config_8_0"] | None: ...

global___ClusterConfig = ClusterConfig

@typing.final
class Host(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Role:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Role.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ROLE_UNKNOWN: Host._Role.ValueType  # 0
        """Role of the host is unknown. Default value."""
        MASTER: Host._Role.ValueType  # 1
        """Host is the master."""
        REPLICA: Host._Role.ValueType  # 2
        """Host is a replica."""

    class Role(_Role, metaclass=_RoleEnumTypeWrapper): ...
    ROLE_UNKNOWN: Host.Role.ValueType  # 0
    """Role of the host is unknown. Default value."""
    MASTER: Host.Role.ValueType  # 1
    """Host is the master."""
    REPLICA: Host.Role.ValueType  # 2
    """Host is a replica."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Host._Health.ValueType  # 0
        """Health of the host is unknown. Default value."""
        ALIVE: Host._Health.ValueType  # 1
        """Host is performing all its functions normally."""
        DEAD: Host._Health.ValueType  # 2
        """Host is inoperable, and cannot perform any of its essential functions."""
        DEGRADED: Host._Health.ValueType  # 3
        """Host is degraded, and can perform only some of its essential functions."""
        READONLY: Host._Health.ValueType  # 4
        """Host is alive, but in read-only mode."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Host.Health.ValueType  # 0
    """Health of the host is unknown. Default value."""
    ALIVE: Host.Health.ValueType  # 1
    """Host is performing all its functions normally."""
    DEAD: Host.Health.ValueType  # 2
    """Host is inoperable, and cannot perform any of its essential functions."""
    DEGRADED: Host.Health.ValueType  # 3
    """Host is degraded, and can perform only some of its essential functions."""
    READONLY: Host.Health.ValueType  # 4
    """Host is alive, but in read-only mode."""

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    SERVICES_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
    REPLICATION_SOURCE_FIELD_NUMBER: builtins.int
    BACKUP_PRIORITY_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the host.

    This name is assigned by the platform at the time of creation.
    The name is unique across all MDB hosts that exist on the platform, as it defines the FQDN of the host.
    """
    cluster_id: builtins.str
    """ID of the cluster the host belongs to."""
    zone_id: builtins.str
    """ID of the availability zone where the host resides."""
    role: global___Host.Role.ValueType
    """Role of the host in the cluster. If the field has default value, it is not returned in the response."""
    health: global___Host.Health.ValueType
    """Aggregated health of the host. If the field has default value, it is not returned in the response."""
    subnet_id: builtins.str
    """ID of the subnet that the host belongs to."""
    assign_public_ip: builtins.bool
    """Flag that shows if public IP address is assigned to the host so that the host can be accessed from the internet."""
    replication_source: builtins.str
    """Name of the host to be used as the replication source for cascading replication."""
    backup_priority: builtins.int
    """Host backup priority."""
    priority: builtins.int
    """Host master promotion priority."""
    @property
    def resources(self) -> global___Resources:
        """Resources allocated to the host."""

    @property
    def services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Service]:
        """List of services provided by the host."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        zone_id: builtins.str = ...,
        resources: global___Resources | None = ...,
        role: global___Host.Role.ValueType = ...,
        health: global___Host.Health.ValueType = ...,
        services: collections.abc.Iterable[global___Service] | None = ...,
        subnet_id: builtins.str = ...,
        assign_public_ip: builtins.bool = ...,
        replication_source: builtins.str = ...,
        backup_priority: builtins.int = ...,
        priority: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assign_public_ip", b"assign_public_ip", "backup_priority", b"backup_priority", "cluster_id", b"cluster_id", "health", b"health", "name", b"name", "priority", b"priority", "replication_source", b"replication_source", "resources", b"resources", "role", b"role", "services", b"services", "subnet_id", b"subnet_id", "zone_id", b"zone_id"]) -> None: ...

global___Host = Host

@typing.final
class Service(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Service._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Service._Type.ValueType  # 0
        """Service type of the host is unspecified. Default value."""
        MYSQL: Service._Type.ValueType  # 1
        """The host is a MySQL server."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: Service.Type.ValueType  # 0
    """Service type of the host is unspecified. Default value."""
    MYSQL: Service.Type.ValueType  # 1
    """The host is a MySQL server."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Service._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Service._Health.ValueType  # 0
        """Health of the service is unknown. Default value."""
        ALIVE: Service._Health.ValueType  # 1
        """The service is working normally."""
        DEAD: Service._Health.ValueType  # 2
        """The service is dead or unresponsive."""
        READONLY: Service._Health.ValueType  # 3
        """The service is in read-only mode."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Service.Health.ValueType  # 0
    """Health of the service is unknown. Default value."""
    ALIVE: Service.Health.ValueType  # 1
    """The service is working normally."""
    DEAD: Service.Health.ValueType  # 2
    """The service is dead or unresponsive."""
    READONLY: Service.Health.ValueType  # 3
    """The service is in read-only mode."""

    TYPE_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    type: global___Service.Type.ValueType
    """Type of the service provided by the host. If the field has default value, it is not returned in the response."""
    health: global___Service.Health.ValueType
    """Aggregated health of the service. If the field has default value, it is not returned in the response."""
    def __init__(
        self,
        *,
        type: global___Service.Type.ValueType = ...,
        health: global___Service.Health.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["health", b"health", "type", b"type"]) -> None: ...

global___Service = Service

@typing.final
class Resources(google.protobuf.message.Message):
    """Cluster resource preset."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    DISK_TYPE_ID_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    """ID of the resource preset that defines available computational resources (vCPU, RAM, etc.) for a cluster host.

    All available presets are listed in [the documentation](/docs/managed-mysql/concepts/instance-types).
    """
    disk_size: builtins.int
    """Volume of the storage (for each cluster host, in bytes)."""
    disk_type_id: builtins.str
    """Type of the storage.

    Possible values:
    * `network-hdd` - standard network storage
    * `network-ssd` - fast network storage
    * `network-ssd-nonreplicated` - fast network nonreplicated storage
    * `local-ssd` - fast local storage.

    See [the documentation](/docs/managed-mysql/concepts/storage) for details.
    """
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
        disk_size: builtins.int = ...,
        disk_type_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_size", b"disk_size", "disk_type_id", b"disk_type_id", "resource_preset_id", b"resource_preset_id"]) -> None: ...

global___Resources = Resources

@typing.final
class Access(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_LENS_FIELD_NUMBER: builtins.int
    WEB_SQL_FIELD_NUMBER: builtins.int
    DATA_TRANSFER_FIELD_NUMBER: builtins.int
    YANDEX_QUERY_FIELD_NUMBER: builtins.int
    data_lens: builtins.bool
    """Allows access from DataLens.

    See [the documentation](/docs/managed-mysql/operations/datalens-connect) for details.
    """
    web_sql: builtins.bool
    """Allows SQL queries to the cluster databases from management console.

    See [the documentation](/docs/managed-mysql/operations/web-sql-query) for details.
    """
    data_transfer: builtins.bool
    """Allow access for DataTransfer."""
    yandex_query: builtins.bool
    """Allow access for YandexQuery."""
    def __init__(
        self,
        *,
        data_lens: builtins.bool = ...,
        web_sql: builtins.bool = ...,
        data_transfer: builtins.bool = ...,
        yandex_query: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["data_lens", b"data_lens", "data_transfer", b"data_transfer", "web_sql", b"web_sql", "yandex_query", b"yandex_query"]) -> None: ...

global___Access = Access

@typing.final
class PerformanceDiagnostics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    SESSIONS_SAMPLING_INTERVAL_FIELD_NUMBER: builtins.int
    STATEMENTS_SAMPLING_INTERVAL_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    """Flag that shows if performance statistics gathering is enabled for the cluster."""
    sessions_sampling_interval: builtins.int
    """Interval (in seconds) for `my_session` sampling."""
    statements_sampling_interval: builtins.int
    """Interval (in seconds) for `my_statements` sampling."""
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        sessions_sampling_interval: builtins.int = ...,
        statements_sampling_interval: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "sessions_sampling_interval", b"sessions_sampling_interval", "statements_sampling_interval", b"statements_sampling_interval"]) -> None: ...

global___PerformanceDiagnostics = PerformanceDiagnostics

@typing.final
class DiskSizeAutoscaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLANNED_USAGE_THRESHOLD_FIELD_NUMBER: builtins.int
    EMERGENCY_USAGE_THRESHOLD_FIELD_NUMBER: builtins.int
    DISK_SIZE_LIMIT_FIELD_NUMBER: builtins.int
    planned_usage_threshold: builtins.int
    """Amount of used storage for automatic disk scaling in the maintenance window, 0 means disabled, in percent."""
    emergency_usage_threshold: builtins.int
    """Amount of used storage for immediately  automatic disk scaling, 0 means disabled, in percent."""
    disk_size_limit: builtins.int
    """Limit on how large the storage for database instances can automatically grow, in bytes."""
    def __init__(
        self,
        *,
        planned_usage_threshold: builtins.int = ...,
        emergency_usage_threshold: builtins.int = ...,
        disk_size_limit: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_size_limit", b"disk_size_limit", "emergency_usage_threshold", b"emergency_usage_threshold", "planned_usage_threshold", b"planned_usage_threshold"]) -> None: ...

global___DiskSizeAutoscaling = DiskSizeAutoscaling



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/postgresql/v1/perf_diag_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/postgresql/v1/perf_diag_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.postgresql.v1 import perf_diag_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_perf__diag__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/mdb/postgresql/v1/perf_diag_service.proto\x12\x1eyandex.cloud.mdb.postgresql.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\x1a.yandex/cloud/mdb/postgresql/v1/perf_diag.proto\"\xd7\x01\n\x18ListRawStatementsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12-\n\tfrom_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\tpage_size\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07<=10000\x12\x1d\n\npage_token\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\xda\x01\n\x1bListRawSessionStatesRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12-\n\tfrom_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\tpage_size\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07<=10000\x12\x1d\n\npage_token\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"}\n\x1cListRawSessionStatesResponse\x12\x44\n\x0esession_states\x18\x01 \x03(\x0b\x32,.yandex.cloud.mdb.postgresql.v1.SessionState\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"x\n\x19ListRawStatementsResponse\x12\x42\n\nstatements\x18\x01 \x03(\x0b\x32..yandex.cloud.mdb.postgresql.v1.QueryStatement\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xbe\x02\n\x1dPerformanceDiagnosticsService\x12\x91\x01\n\x14ListRawSessionStates\x12;.yandex.cloud.mdb.postgresql.v1.ListRawSessionStatesRequest\x1a<.yandex.cloud.mdb.postgresql.v1.ListRawSessionStatesResponse\x12\x88\x01\n\x11ListRawStatements\x12\x38.yandex.cloud.mdb.postgresql.v1.ListRawStatementsRequest\x1a\x39.yandex.cloud.mdb.postgresql.v1.ListRawStatementsResponseBs\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.postgresql.v1.perf_diag_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresql'
  _globals['_LISTRAWSTATEMENTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTRAWSTATEMENTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTRAWSTATEMENTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTRAWSTATEMENTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\007<=10000'
  _globals['_LISTRAWSTATEMENTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTRAWSTATEMENTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTRAWSESSIONSTATESREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTRAWSESSIONSTATESREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTRAWSESSIONSTATESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTRAWSESSIONSTATESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\007<=10000'
  _globals['_LISTRAWSESSIONSTATESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTRAWSESSIONSTATESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTRAWSTATEMENTSREQUEST']._serialized_start=203
  _globals['_LISTRAWSTATEMENTSREQUEST']._serialized_end=418
  _globals['_LISTRAWSESSIONSTATESREQUEST']._serialized_start=421
  _globals['_LISTRAWSESSIONSTATESREQUEST']._serialized_end=639
  _globals['_LISTRAWSESSIONSTATESRESPONSE']._serialized_start=641
  _globals['_LISTRAWSESSIONSTATESRESPONSE']._serialized_end=766
  _globals['_LISTRAWSTATEMENTSRESPONSE']._serialized_start=768
  _globals['_LISTRAWSTATEMENTSRESPONSE']._serialized_end=888
  _globals['_PERFORMANCEDIAGNOSTICSSERVICE']._serialized_start=891
  _globals['_PERFORMANCEDIAGNOSTICSSERVICE']._serialized_end=1209
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cic/v1/private_connection_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cic/v1/private_connection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.cic.v1 import peering_pb2 as yandex_dot_cloud_dot_cic_dot_v1_dot_peering__pb2
from yandex.cloud.cic.v1 import private_connection_pb2 as yandex_dot_cloud_dot_cic_dot_v1_dot_private__connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/cic/v1/private_connection_service.proto\x12\x13yandex.cloud.cic.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a!yandex/cloud/cic/v1/peering.proto\x1a,yandex/cloud/cic/v1/private_connection.proto\"J\n\x1bGetPrivateConnectionRequest\x12+\n\x15private_connection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x9a\x01\n\x1dListPrivateConnectionsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"~\n\x1eListPrivateConnectionsResponse\x12\x43\n\x13private_connections\x18\x01 \x03(\x0b\x32&.yandex.cloud.cic.v1.PrivateConnection\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8e\x04\n\x1e\x43reatePrivateConnectionRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x04 \x01(\t\x12\x11\n\tregion_id\x18\x05 \x01(\t\x12\x1b\n\x13trunk_connection_id\x18\x06 \x01(\t\x12,\n\x07vlan_id\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\x0cipv4_peering\x18\n \x01(\x0b\x32\x1c.yandex.cloud.cic.v1.Peering\x12N\n\x12ipv4_static_routes\x18\x13 \x03(\x0b\x32\x32.yandex.cloud.cic.v1.PrivateConnection.StaticRoute\x12\x8c\x01\n\x06labels\x18\x1a \x03(\x0b\x32?.yandex.cloud.cic.v1.CreatePrivateConnectionRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x03\x10\x04J\x04\x08\x08\x10\nJ\x04\x08\x0b\x10\x13J\x04\x08\x14\x10\x1a\"@\n\x1f\x43reatePrivateConnectionMetadata\x12\x1d\n\x15private_connection_id\x18\x01 \x01(\t\"\xd3\x04\n\x1eUpdatePrivateConnectionRequest\x12+\n\x15private_connection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tregion_id\x18\x07 \x01(\t\x12\x1b\n\x13trunk_connection_id\x18\x08 \x01(\t\x12,\n\x07vlan_id\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\x0cipv4_peering\x18\n \x01(\x0b\x32\x1c.yandex.cloud.cic.v1.Peering\x12N\n\x12ipv4_static_routes\x18\x13 \x03(\x0b\x32\x32.yandex.cloud.cic.v1.PrivateConnection.StaticRoute\x12\x8c\x01\n\x06labels\x18\x1a \x03(\x0b\x32?.yandex.cloud.cic.v1.UpdatePrivateConnectionRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x05\x10\x07J\x04\x08\x0b\x10\x13J\x04\x08\x14\x10\x1a\"@\n\x1fUpdatePrivateConnectionMetadata\x12\x1d\n\x15private_connection_id\x18\x01 \x01(\t\"M\n\x1e\x44\x65letePrivateConnectionRequest\x12+\n\x15private_connection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"@\n\x1f\x44\x65letePrivateConnectionMetadata\x12\x1d\n\x15private_connection_id\x18\x01 \x01(\t\"\x9d\x01\n\x18UpsertStaticRouteRequest\x12+\n\x15private_connection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12N\n\x12ipv4_static_routes\x18\x02 \x03(\x0b\x32\x32.yandex.cloud.cic.v1.PrivateConnection.StaticRouteJ\x04\x08\x03\x10\x04\":\n\x19UpsertStaticRouteMetadata\x12\x1d\n\x15private_connection_id\x18\x01 \x01(\t\"\x9d\x01\n\x18RemoveStaticRouteRequest\x12+\n\x15private_connection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12N\n\x12ipv4_static_routes\x18\x02 \x03(\x0b\x32\x32.yandex.cloud.cic.v1.PrivateConnection.StaticRouteJ\x04\x08\x03\x10\x04\":\n\x19RemoveStaticRouteMetadata\x12\x1d\n\x15private_connection_id\x18\x01 \x01(\t\"\x93\x01\n&ListPrivateConnectionOperationsRequest\x12+\n\x15private_connection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"y\n\'ListPrivateConnectionOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xfc\x0c\n\x18PrivateConnectionService\x12\x9b\x01\n\x03Get\x12\x30.yandex.cloud.cic.v1.GetPrivateConnectionRequest\x1a&.yandex.cloud.cic.v1.PrivateConnection\":\x82\xd3\xe4\x93\x02\x34\x12\x32/cic/v1/privateConnections/{private_connection_id}\x12\x93\x01\n\x04List\x12\x32.yandex.cloud.cic.v1.ListPrivateConnectionsRequest\x1a\x33.yandex.cloud.cic.v1.ListPrivateConnectionsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/cic/v1/privateConnections\x12\xbf\x01\n\x06\x43reate\x12\x33.yandex.cloud.cic.v1.CreatePrivateConnectionRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*4\n\x1f\x43reatePrivateConnectionMetadata\x12\x11PrivateConnection\x82\xd3\xe4\x93\x02\x1f\"\x1a/cic/v1/privateConnections:\x01*\x12\xd7\x01\n\x06Update\x12\x33.yandex.cloud.cic.v1.UpdatePrivateConnectionRequest\x1a!.yandex.cloud.operation.Operation\"u\xb2\xd2*4\n\x1fUpdatePrivateConnectionMetadata\x12\x11PrivateConnection\x82\xd3\xe4\x93\x02\x37\x32\x32/cic/v1/privateConnections/{private_connection_id}:\x01*\x12\xd8\x01\n\x06\x44\x65lete\x12\x33.yandex.cloud.cic.v1.DeletePrivateConnectionRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*8\n\x1f\x44\x65letePrivateConnectionMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x34*2/cic/v1/privateConnections/{private_connection_id}\x12\xee\x01\n\x11UpsertStaticRoute\x12-.yandex.cloud.cic.v1.UpsertStaticRouteRequest\x1a!.yandex.cloud.operation.Operation\"\x86\x01\xb2\xd2*2\n\x19UpsertStaticRouteMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02J\"E/cic/v1/privateConnections/{private_connection_id}:upsertStaticRoutes:\x01*\x12\xee\x01\n\x11RemoveStaticRoute\x12-.yandex.cloud.cic.v1.RemoveStaticRouteRequest\x1a!.yandex.cloud.operation.Operation\"\x86\x01\xb2\xd2*2\n\x19RemoveStaticRouteMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02J\"E/cic/v1/privateConnections/{private_connection_id}:removeStaticRoutes:\x01*\x12\xd2\x01\n\x0eListOperations\x12;.yandex.cloud.cic.v1.ListPrivateConnectionOperationsRequest\x1a<.yandex.cloud.cic.v1.ListPrivateConnectionOperationsResponse\"E\x82\xd3\xe4\x93\x02?\x12=/cic/v1/privateConnections/{private_connection_id}/operationsBV\n\x17yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cicb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cic.v1.private_connection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cic'
  _globals['_GETPRIVATECONNECTIONREQUEST'].fields_by_name['private_connection_id']._loaded_options = None
  _globals['_GETPRIVATECONNECTIONREQUEST'].fields_by_name['private_connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTPRIVATECONNECTIONSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTPRIVATECONNECTIONSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTPRIVATECONNECTIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPRIVATECONNECTIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTPRIVATECONNECTIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTPRIVATECONNECTIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTPRIVATECONNECTIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTPRIVATECONNECTIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATEPRIVATECONNECTIONREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEPRIVATECONNECTIONREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEPRIVATECONNECTIONREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEPRIVATECONNECTIONREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATEPRIVATECONNECTIONREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEPRIVATECONNECTIONREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEPRIVATECONNECTIONREQUEST'].fields_by_name['private_connection_id']._loaded_options = None
  _globals['_UPDATEPRIVATECONNECTIONREQUEST'].fields_by_name['private_connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEPRIVATECONNECTIONREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEPRIVATECONNECTIONREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETEPRIVATECONNECTIONREQUEST'].fields_by_name['private_connection_id']._loaded_options = None
  _globals['_DELETEPRIVATECONNECTIONREQUEST'].fields_by_name['private_connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPSERTSTATICROUTEREQUEST'].fields_by_name['private_connection_id']._loaded_options = None
  _globals['_UPSERTSTATICROUTEREQUEST'].fields_by_name['private_connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_REMOVESTATICROUTEREQUEST'].fields_by_name['private_connection_id']._loaded_options = None
  _globals['_REMOVESTATICROUTEREQUEST'].fields_by_name['private_connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTPRIVATECONNECTIONOPERATIONSREQUEST'].fields_by_name['private_connection_id']._loaded_options = None
  _globals['_LISTPRIVATECONNECTIONOPERATIONSREQUEST'].fields_by_name['private_connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTPRIVATECONNECTIONOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPRIVATECONNECTIONOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTPRIVATECONNECTIONOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTPRIVATECONNECTIONOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_PRIVATECONNECTIONSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_PRIVATECONNECTIONSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0024\0222/cic/v1/privateConnections/{private_connection_id}'
  _globals['_PRIVATECONNECTIONSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_PRIVATECONNECTIONSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\034\022\032/cic/v1/privateConnections'
  _globals['_PRIVATECONNECTIONSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_PRIVATECONNECTIONSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*4\n\037CreatePrivateConnectionMetadata\022\021PrivateConnection\202\323\344\223\002\037\"\032/cic/v1/privateConnections:\001*'
  _globals['_PRIVATECONNECTIONSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_PRIVATECONNECTIONSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*4\n\037UpdatePrivateConnectionMetadata\022\021PrivateConnection\202\323\344\223\002722/cic/v1/privateConnections/{private_connection_id}:\001*'
  _globals['_PRIVATECONNECTIONSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_PRIVATECONNECTIONSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*8\n\037DeletePrivateConnectionMetadata\022\025google.protobuf.Empty\202\323\344\223\0024*2/cic/v1/privateConnections/{private_connection_id}'
  _globals['_PRIVATECONNECTIONSERVICE'].methods_by_name['UpsertStaticRoute']._loaded_options = None
  _globals['_PRIVATECONNECTIONSERVICE'].methods_by_name['UpsertStaticRoute']._serialized_options = b'\262\322*2\n\031UpsertStaticRouteMetadata\022\025google.protobuf.Empty\202\323\344\223\002J\"E/cic/v1/privateConnections/{private_connection_id}:upsertStaticRoutes:\001*'
  _globals['_PRIVATECONNECTIONSERVICE'].methods_by_name['RemoveStaticRoute']._loaded_options = None
  _globals['_PRIVATECONNECTIONSERVICE'].methods_by_name['RemoveStaticRoute']._serialized_options = b'\262\322*2\n\031RemoveStaticRouteMetadata\022\025google.protobuf.Empty\202\323\344\223\002J\"E/cic/v1/privateConnections/{private_connection_id}:removeStaticRoutes:\001*'
  _globals['_PRIVATECONNECTIONSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_PRIVATECONNECTIONSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002?\022=/cic/v1/privateConnections/{private_connection_id}/operations'
  _globals['_GETPRIVATECONNECTIONREQUEST']._serialized_start=359
  _globals['_GETPRIVATECONNECTIONREQUEST']._serialized_end=433
  _globals['_LISTPRIVATECONNECTIONSREQUEST']._serialized_start=436
  _globals['_LISTPRIVATECONNECTIONSREQUEST']._serialized_end=590
  _globals['_LISTPRIVATECONNECTIONSRESPONSE']._serialized_start=592
  _globals['_LISTPRIVATECONNECTIONSRESPONSE']._serialized_end=718
  _globals['_CREATEPRIVATECONNECTIONREQUEST']._serialized_start=721
  _globals['_CREATEPRIVATECONNECTIONREQUEST']._serialized_end=1247
  _globals['_CREATEPRIVATECONNECTIONREQUEST_LABELSENTRY']._serialized_start=1178
  _globals['_CREATEPRIVATECONNECTIONREQUEST_LABELSENTRY']._serialized_end=1223
  _globals['_CREATEPRIVATECONNECTIONMETADATA']._serialized_start=1249
  _globals['_CREATEPRIVATECONNECTIONMETADATA']._serialized_end=1313
  _globals['_UPDATEPRIVATECONNECTIONREQUEST']._serialized_start=1316
  _globals['_UPDATEPRIVATECONNECTIONREQUEST']._serialized_end=1911
  _globals['_UPDATEPRIVATECONNECTIONREQUEST_LABELSENTRY']._serialized_start=1178
  _globals['_UPDATEPRIVATECONNECTIONREQUEST_LABELSENTRY']._serialized_end=1223
  _globals['_UPDATEPRIVATECONNECTIONMETADATA']._serialized_start=1913
  _globals['_UPDATEPRIVATECONNECTIONMETADATA']._serialized_end=1977
  _globals['_DELETEPRIVATECONNECTIONREQUEST']._serialized_start=1979
  _globals['_DELETEPRIVATECONNECTIONREQUEST']._serialized_end=2056
  _globals['_DELETEPRIVATECONNECTIONMETADATA']._serialized_start=2058
  _globals['_DELETEPRIVATECONNECTIONMETADATA']._serialized_end=2122
  _globals['_UPSERTSTATICROUTEREQUEST']._serialized_start=2125
  _globals['_UPSERTSTATICROUTEREQUEST']._serialized_end=2282
  _globals['_UPSERTSTATICROUTEMETADATA']._serialized_start=2284
  _globals['_UPSERTSTATICROUTEMETADATA']._serialized_end=2342
  _globals['_REMOVESTATICROUTEREQUEST']._serialized_start=2345
  _globals['_REMOVESTATICROUTEREQUEST']._serialized_end=2502
  _globals['_REMOVESTATICROUTEMETADATA']._serialized_start=2504
  _globals['_REMOVESTATICROUTEMETADATA']._serialized_end=2562
  _globals['_LISTPRIVATECONNECTIONOPERATIONSREQUEST']._serialized_start=2565
  _globals['_LISTPRIVATECONNECTIONOPERATIONSREQUEST']._serialized_end=2712
  _globals['_LISTPRIVATECONNECTIONOPERATIONSRESPONSE']._serialized_start=2714
  _globals['_LISTPRIVATECONNECTIONOPERATIONSRESPONSE']._serialized_end=2835
  _globals['_PRIVATECONNECTIONSERVICE']._serialized_start=2838
  _globals['_PRIVATECONNECTIONSERVICE']._serialized_end=4498
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/compute/v1/placement_group.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/compute/v1/placement_group.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/compute/v1/placement_group.proto\x12\x17yandex.cloud.compute.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xc6\x03\n\x0ePlacementGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x43\n\x06labels\x18\x06 \x03(\x0b\x32\x33.yandex.cloud.compute.v1.PlacementGroup.LabelsEntry\x12U\n\x19spread_placement_strategy\x18\x07 \x01(\x0b\x32\x30.yandex.cloud.compute.v1.SpreadPlacementStrategyH\x00\x12[\n\x1cpartition_placement_strategy\x18\x08 \x01(\x0b\x32\x33.yandex.cloud.compute.v1.PartitionPlacementStrategyH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x1a\n\x12placement_strategy\x12\x04\xc0\xc1\x31\x01\"\x19\n\x17SpreadPlacementStrategy\"9\n\x1aPartitionPlacementStrategy\x12\x1b\n\npartitions\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03\x32-5Bb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.placement_group_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _globals['_PLACEMENTGROUP_LABELSENTRY']._loaded_options = None
  _globals['_PLACEMENTGROUP_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_PLACEMENTGROUP'].oneofs_by_name['placement_strategy']._loaded_options = None
  _globals['_PLACEMENTGROUP'].oneofs_by_name['placement_strategy']._serialized_options = b'\300\3011\001'
  _globals['_PARTITIONPLACEMENTSTRATEGY'].fields_by_name['partitions']._loaded_options = None
  _globals['_PARTITIONPLACEMENTSTRATEGY'].fields_by_name['partitions']._serialized_options = b'\372\3071\0032-5'
  _globals['_PLACEMENTGROUP']._serialized_start=139
  _globals['_PLACEMENTGROUP']._serialized_end=593
  _globals['_PLACEMENTGROUP_LABELSENTRY']._serialized_start=520
  _globals['_PLACEMENTGROUP_LABELSENTRY']._serialized_end=565
  _globals['_SPREADPLACEMENTSTRATEGY']._serialized_start=595
  _globals['_SPREADPLACEMENTSTRATEGY']._serialized_end=620
  _globals['_PARTITIONPLACEMENTSTRATEGY']._serialized_start=622
  _globals['_PARTITIONPLACEMENTSTRATEGY']._serialized_end=679
# @@protoc_insertion_point(module_scope)
